@@ -1,7 +1,7 @@
 package Finance::Bank::ID::BCA;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2015-09-08'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use Moo;
@@ -340,16 +340,18 @@ sub _ps_get_transactions {
         push @e, {date=>$1, desc=>$2, br=>$3, amt=>$4, amtf=>$5, crdb=>$6, bal=>$7, balf=>$8};
     }
     if (!@e) {
+        say "D1";
         # HTML version
         while ($page =~ m!^
 <tr>\s*
-  <td[^>]+>(?:<[^>]+>\s*)*  (\d\d/\d\d|\s?PEND|\s?NEXT)  (?:<[^>]+>\s*)*</td>\s*
-  <td[^>]+>(?:<[^>]+>\s*)*  ((?:[^\t]|\n)*?)             (?:<[^>]+>\s*)*</td>\s*
-  <td[^>]+>(?:<[^>]+>\s*)*  (\d{4})                      (?:<[^>]+>\s*)*</td>\s*
-  <td[^>]+>(?:<[^>]+>\s*)*  ([0-9,]+)\.(\d\d)            (?:<[^>]+>\s*)*</td>\s*
-  <td[^>]+>(?:<[^>]+>\s*)*  (CR|DB)                      (?:<[^>]+>\s*)*</td>\s*
-  <td[^>]+>(?:<[^>]+>\s*)*  ([0-9,]+)\.(\d\d)            (?:<[^>]+>\s*)*</td>\s*
-</tr>!smxg) {
+  <td[^>]+>(?:\s*<[^>]+>\s*)*  (\d\d/\d\d|\s?PEND|\s?NEXT)  (?:\s*<[^>]+>\s*)*</td>\s*
+  <td[^>]+>(?:\s*<[^>]+>\s*)*  ((?:[^\t]|\n)*?)             (?:\s*<[^>]+>\s*)*</td>\s*
+  <td[^>]+>(?:\s*<[^>]+>\s*)*  (\d{4})                      (?:\s*<[^>]+>\s*)*</td>\s*
+  <td[^>]+>(?:\s*<[^>]+>\s*)*  ([0-9,]+)\.(\d\d)            (?:\s*<[^>]+>\s*)*</td>\s*
+  <td[^>]+>(?:\s*<[^>]+>\s*)*  (CR|DB)                      (?:\s*<[^>]+>\s*)*</td>\s*
+  <td[^>]+>(?:\s*<[^>]+>\s*)*  ([0-9,]+)\.(\d\d)            (?:\s*<[^>]+>\s*)*</td>\s*
+</tr>
+                         !smxg) {
             push @e, {date=>$1, desc=>$2, br=>$3, amt=>$4, amtf=>$5, crdb=>$6, bal=>$7, balf=>$8};
         }
         for (@e) { $_->{desc} =~ s!<br ?/?>!\n!ig }
@@ -448,7 +450,7 @@ Finance::Bank::ID::BCA - Check your BCA accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.41 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2015-09-03.
+This document describes version 0.42 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2015-09-08.
 
 =head1 SYNOPSIS
 
@@ -493,12 +495,15 @@ If you want to use the library in your Perl application:
             print "$tx->{date} $tx->{amount} $tx->{description}\n";
         }
     };
+    warn if $@;
 
     # remember to call this, otherwise you will have trouble logging in again
     # for some time
-    if ($ibank->logged_in) { $ibank->logout() }
+    $ibank->logout();
 
-    # utility routines
+Utility routines:
+
+    # parse HTML statement directly
     my $res = $ibank->parse_statement($html);
 
 =head1 DESCRIPTION
